/******************************************************************************
 *
 *  (C)Copyright 2009 Marvell. All Rights Reserved.
 *  
 *  THIS IS UNPUBLISHED PROPRIETARY SOURCE CODE OF MARVELL.
 *  The copyright notice above does not evidence any actual or intended 
 *  publication of such source code.
 *  This Module contains Proprietary Information of Marvell and should be
 *  treated as Confidential.
 *  The information in this file is provided for the exclusive use of the 
 *  licensees of Marvell.
 *  Such users have the right to use, modify, and incorporate this code into 
 *  products for purposes authorized by the license agreement provided they 
 *  include this notice and the associated copyright notice with any such
 *  product. 
 *  The information in this file is provided "AS IS" without warranty.
 *
 ******************************************************************************/

#pragma once
#include "Macrodef.h"
#include "ReservedPackageData.h"
#include "TimLib.h"

class  CErdBase : public CTimLib
{
public:

	enum ERD_PKG_TYPE { UNKNOWN_ERD = 0,
		AUTOBIND_ERD = 100,
		ESCAPESEQ_ERD,
		GPIOSET_ERD,
		GPIO_ERD,
		RESUME_ERD, // obsolete but kept to maintain pkg type id
		RESUME_DDR_ERD,
		TBRXFER_ERD,
		XFER_ERD,
		UART_ERD,
		USB_ERD,
		USBVENDORREQ_ERD,
		CONSUMER_ID_ERD,
		GPP_INITIALIZATION_ERD,
		DDR_INITIALIZATION_ERD,
		INSTRUCTIONS_ERD,
		DDR_OPERATIONS_ERD,
		GPP_OPERATIONS_ERD,
		CORE_ID_ERD,
		TZ_INITIALIZATION_ERD,
		TZ_OPERATIONS_ERD,
		BBMT_ERD,
		IMAGE_MAPS_ERD,
		IMAGE_MAP_INFO_ERD,
		MAX_ERD_PACKAGES = ( BBMT_ERD - 100 + 2 )
	};

	CErdBase( ERD_PKG_TYPE ErdType, int iMaxFieldNum );
	virtual ~CErdBase(void);

	// copy constructor
	CErdBase( const CErdBase& rhs );
	// assignment operator
	virtual CErdBase& operator=( const CErdBase& rhs );

	virtual void Reset();

	ERD_PKG_TYPE ErdPkgType();
	static CErdBase* Create( ERD_PKG_TYPE ErdPkgType );
	static CErdBase* Create( CErdBase& src );
	static CErdBase* Create( tstring& sPackageName );


    virtual bool ReadBLF(tifstream& ifsBlf,tstring sErdLine );
	virtual bool WriteBLF( tofstream& ofs);
	virtual unsigned int PackageSize(){ return 0; }
	virtual const tstring& PackageName() = 0;
	virtual const tstring& PackageEndName() = 0;
	virtual int AddPkgStrings( CReservedPackageData* pRPD ) = 0;

	unsigned int MaxFieldNum();
	t_stringVector& FieldNames();
	t_stringVector& FieldValues();
	t_stringVector& FieldComments();



protected:
	ERD_PKG_TYPE	 m_eErdType;

	unsigned int	m_iMaxFieldNum;
	t_stringVector	m_FieldNames;
	t_stringVector	m_FieldValues;
	t_stringVector	m_FieldComments;
};

typedef vector<CErdBase*>           t_ErdBaseVector;
typedef vector<CErdBase*>::iterator t_ErdBaseVectorIter;

