/******************************************************************************
 *
 *  (C)Copyright 2005 - 2009 Marvell. All Rights Reserved.
 *  
 *  THIS IS UNPUBLISHED PROPRIETARY SOURCE CODE OF MARVELL.
 *  The copyright notice above does not evidence any actual or intended 
 *  publication of such source code.
 *  This Module contains Proprietary Information of Marvell and should be
 *  treated as Confidential.
 *  The information in this file is provided for the exclusive use of the 
 *  licensees of Marvell.
 *  Such users have the right to use, modify, and incorporate this code into 
 *  products for purposes authorized by the license agreement provided they 
 *  include this notice and the associated copyright notice with any such
 *  product. 
 *  The information in this file is provided "AS IS" without warranty.
 *
 ******************************************************************************/

#pragma once
#include "Macrodef.h"
#include <list>
#include <iterator>
#include <vector>
using namespace std;
#include  "ConsumerID.h"
#include "TimLib.h"
#include "ReservedPackageData.h"
#include "ErdBase.h"
#include "Typedef.h"	// Added by ClassView
#if !defined (LINUX)
#include <tchar.h>
#else
#include <stdio.h>
#endif
typedef vector<tstring*>           t_stringVector;
typedef vector<tstring*>::iterator t_stringVectorIter;
typedef list<pair<unsigned int,unsigned int>*>			 t_PairList;
typedef list<pair<unsigned int,unsigned int>*>::iterator t_PairListIter;



class  CExtendedReservedData: public CTimLib
{
public:
	CExtendedReservedData(const tstring& sProcessorType);
	virtual~CExtendedReservedData(void);
    
   // copy constructor
	CExtendedReservedData( const CExtendedReservedData& rhs );
	// assignment operator
	CExtendedReservedData& operator=( const CExtendedReservedData& rhs );

	bool IsChanged();
	void Changed( bool bSet );

	bool IsIMAPChanged();
	void IMAPChanged(bool bSet);

	void AddClockEnableField( pair< unsigned int, unsigned int >* field );
	
	void AddDDRGeometryField( pair< unsigned int, unsigned int >* field );
		
	void AddDDRTimingField( pair< unsigned int, unsigned int >* field );

	void AddDDRCustomField( pair< unsigned int, unsigned int >* field );

	void AddTTCDDRCustomField( pair< unsigned int, unsigned int >* field );
		
	void AddFrequencyField( pair< unsigned int, unsigned int >* field );
		

	void AddVoltagesField( pair< unsigned int, unsigned int >* field );
		
	void AddConfigMemoryControlField( pair< unsigned int, unsigned int >* field );
		
	void AddTrustZoneField( pair< unsigned int, unsigned int >* field );
		
	void AddTrustZoneRegidField( pair< unsigned int, unsigned int >* field );
		
	void AddOpDivField( pair< unsigned int, unsigned int >* field );
	
	void AddOpModeField( pair< unsigned int, unsigned int >* field );
		
	int Combine(t_ReservedDataList& ReservedDataList,unsigned int eBlfVer);

	int Size();
	void Reset();
    void DisCardAll();
	int AddPkg(const tstring& sSectionTag, t_PairList& Fields, t_ReservedDataList& ReservedDataList);
    bool ParseERDPackage( tifstream& ifsBlf, tstring sLine,CErdBase*& pErd);
	void ProcessorType( const tstring& sProcessorType );
	tstring& ProcessorType();

	 bool SearchFieldValue( tstring& sLine, unsigned int& idx, t_stringVector& Fields, DWORD& dwValue );

     bool ReadBLF(TCHAR *pszBLFName);
	 bool WriteBLF(tofstream& ofs);
	 bool WritePxa92xBLF(tofstream& ofs);
	 

	void DepopulateExtendedReservedDataFields();
	void Depopulate( t_stringVector& Fields );

	t_stringVector g_ClockEnableFields;	// CLKE ids: See *_CLOCK_ID_T for a list of ids.
	t_stringVector g_DDRCustomFields;	// DDRC ids: See *_MCU_REGID_T for a list of ids.
	t_stringVector g_TTCDDRCustomFields;	// DDRC ids: See *_MCU_REGID_T for a list of ids.
	t_stringVector g_FrequencyFields;	// FREQ ids: See *_FREQ_ID_T for a list of ids.

	t_stringVector g_SdramSpecFields;	// DDRG, DDRT ids: See SDRAM_SPEC_T for a list of ids.  
	t_stringVector g_VoltagesFields;	// TBD

	t_stringVector g_ConfigMemoryControlFields; // CCMC ids
	t_stringVector g_TrustZoneFields; // TZID ids
	t_stringVector g_TrustZoneRegidFields; // TZON ids

	t_stringVector g_OpDivFields;  // Opdv ids
	t_stringVector g_OpModeFields; // Mode ids



	t_PairList	ClockEnableFields;
	t_PairList	DDRGeometryFields;
	t_PairList	DDRTimingFields;
	t_PairList	DDRCustomFields;
	t_PairList	TTCDDRCustomFields;
	t_PairList	FrequencyFields;
	t_PairList	VoltagesFields;
	t_PairList  ConfigMemoryControlFields;
	t_PairList  TrustZoneFields;
	t_PairList  TrustZoneRegidFields;
	t_PairList  OpDivFields;
	t_PairList  OpModeFields;
    t_PairList  EraseAllField;

	t_ErdBaseVector  ErdVec;
	bool m_bChanged;
	bool m_bIMAPChanged;
	tstring m_sProcessorType;
	int m_size;

	t_ConsumerIDVec   m_Consumers;

	private:
	bool ProcessorSpecificFields( const tstring& sProcessor );
	void CopyFields( t_PairList& Fields, t_PairList& nc_rhsFields );
	void RemoveFieldRefs( t_PairList& Fields );
	
};




