// TimDescriptor.h: interface for the CTimDescriptor class.
//
//////////////////////////////////////////////////////////////////////

#pragma once

#include "Macrodef.h"
#include "ReservedPackageData.h"
#include "TimLib.h"
#include "Tim.h"
#include "ImageDescription.h"
#include "ExtendedReservedData.h"
#include "Key.h"
#include "DigitalSignature.h"

class   CTimDescriptor : public CTimLib
{
public:
	CTimDescriptor(void);
	virtual ~CTimDescriptor(void);

	// copy constructor
	CTimDescriptor( const CTimDescriptor& rhs );
	// assignment operator
	CTimDescriptor& operator=( const CTimDescriptor& rhs );

	void TimDescriptorFilePath( tstring& sFilePath ) ;
	tstring& TimDescriptorFilePath() ;

	void Version( tstring& sVersion ) ;
	tstring& Version() ;

	void Trusted( bool bSet ) ;
	bool Trusted() ;
    
	void IssueDate( tstring& sIssueDate ) ;
	tstring& IssueDate();

	void OemUniqueId( tstring& sOemUniqueId ) ;
	tstring& OemUniqueId() ;

	void BootRomFlashSignature( tstring& sBootRomFlashSignature );
	tstring& BootRomFlashSignature() ;

	CImageDescription* Image( int idx );
	bool AddImage( CImageDescription* pImage );
	bool DeleteImage( CImageDescription* pImage );
	size_t ImagesCount();

	bool KeysIsChanged() ;
	void KeysChanged( bool bSet ) ;

	void WtmSaveStateFlashSignature( tstring& sSignature ) ;
	tstring& WtmSaveStateFlashSignature() ;

	void WtmSaveStateFlashEntryAddress( tstring& sAddress ) ;
	tstring& WtmSaveStateFlashEntryAddress();

	void WtmSaveStateBackupEntryAddress( tstring& sAddress ) ;
	tstring& WtmSaveStateBackupEntryAddress() ;

	tstring& TimDescriptor() ;
    
    void TimHeader( CTIM& TimHeader ) ;
	CTIM& TimHeader() ;

	void ProcessorType( tstring& sProcessor ) ;
	tstring& ProcessorType();


    void ImagesList(t_ImagesList& ImagesList ) ;
	t_ImagesList& ImagesList();
	bool UpdateNextImageIds();

	t_ReservedDataList& ReservedDataList();
	int ReservedDataTotalSize();
    
	PLAT_DS& GetPlatDs() ;
	void SetPlatDs( PLAT_DS& Ds ) ;


	CExtendedReservedData& ExtendedReservedData();


	t_KeyList& KeyList();
	CDigitalSignature& DigitalSignature() ;
    void DigitalSignature(CDigitalSignature& DigitalSignature) ;

	bool IsChanged();
	void Changed( bool bSet );
	bool IsNotWritten() ;
	void NotWritten( bool bSet ) ;

	bool ImagesIsChanged() ;
	void ImagesChanged( bool bSet ) ;

	bool ReservedIsChanged() ;
	void ReservedChanged( bool bSet );

	void Reset();
	unsigned int GetTimImageSize( bool bOneNANDPadding /* = false */, unsigned int uiPaddedSize /* = 0 */ ); 

	CKey*& DTimKey() { return m_pDTimKey; }
	void DTimKey( CKey* pKey ) { delete m_pDTimKey; m_pDTimKey = pKey; }

	
	//UINT_T m_RsaPrivateKey[MAXRSAKEYSIZEWORDS];
	//UINT_T m_ECDSAPrivateKey[MAXECCKEYSIZEWORDS];
	void DiscardAll();


private:
	tstring	m_sVersion;
	bool	m_bTrusted;
	tstring	m_sIssueDate;
	tstring	m_sOemUniqueId;
	tstring	m_sBootRomFlashSignature;
	tstring	m_sProcessorType;
	tstring	m_sWtmSaveStateFlashSignature;
	tstring  m_sWtmSaveStateFlashEntryAddress;
	tstring	m_sWtmSaveStateBackupEntryAddress;
    CTIM    m_TimHeader;
	t_ImagesList			m_Images;
	t_ReservedDataList		m_ReservedDataList;

	CExtendedReservedData	m_ExtendedReservedData;


	CDigitalSignature		m_DigitalSignature;
	t_KeyList				m_KeyList;
    PLAT_DS                 m_Ds;
	CKey*                   m_pDTimKey;

	bool m_bChanged;
	bool m_bImagesChanged;
	bool m_bReservedChanged;
	bool m_bKeysChanged;
	bool m_bNotWritten;
};
